==> ros-lunar-plotjuggler_1.2.0.orig.tar.gz: ros-lunar-plotjuggler-1.2.0/plugins/ROS/DataStreamROS/datastream_ROS.h <==
#ifndef DATASTREAM_ROS_TOPIC_H
#define DATASTREAM_ROS_TOPIC_H

#include <QtPlugin>
#include <QAction>
#include <thread>
#include <topic_tools/shape_shifter.h>
#include "PlotJuggler/datastreamer_base.h"
#include <ros_type_introspection/ros_introspection.hpp>


class  DataStreamROS: public QObject, DataStreamer
{
    Q_OBJECT
    Q_PLUGIN_METADATA(IID "com.icarustechnology.PlotJuggler.DataStreamer" "../datastreamer.json")
    Q_INTERFACES(DataStreamer)

public:

    DataStreamROS();

    virtual PlotDataMap &getDataMap() override;

    virtual bool start(QString& default_configuration) override;

    virtual void shutdown() override;

    virtual void enableStreaming(bool enable) override;

    virtual bool isStreamingEnabled() const override;

    virtual ~DataStreamROS() override;

    virtual const char* name() const override { return "ROS Topic Streamer";  }

    virtual void setParentMenu(QMenu* menu) override;

private:

    void topicCallback(const topic_tools::ShapeShifter::ConstPtr& msg, const std::string &topic_name);

    void updateLoop();

    PlotDataMap _plot_data;

    bool _enabled;
    bool _running;

    std::thread _thread;

    void extractInitialSamples();

    double _initial_time;
    bool _use_header_timestamp;

    ros::NodeHandlePtr _node;
    std::vector<ros::Subscriber> _subscribers;
    RosIntrospection::SubstitutionRuleMap _rules;

    int _received_msg_count;

    QAction* _action_saveIntoRosbag;

    std::map<std::string, int> _msg_index;

private slots:

    void saveIntoRosbag();
};

#endif // DATALOAD_CSV_H

==> ros-lunar-plotjuggler_1.5.0.orig.tar.gz: ros-lunar-plotjuggler-1.5.0/plugins/ROS/DataStreamROS/datastream_ROS.h <==
#ifndef DATASTREAM_ROS_TOPIC_H
#define DATASTREAM_ROS_TOPIC_H

#include <QtPlugin>
#include <QAction>
#include <thread>
#include <topic_tools/shape_shifter.h>
#include "PlotJuggler/datastreamer_base.h"
#include <ros_type_introspection/ros_introspection.hpp>


class  DataStreamROS: public QObject, DataStreamer
{
    Q_OBJECT
    Q_PLUGIN_METADATA(IID "com.icarustechnology.PlotJuggler.DataStreamer" "../datastreamer.json")
    Q_INTERFACES(DataStreamer)

public:

    DataStreamROS();

    virtual PlotDataMap &getDataMap() override;

    virtual bool start() override;

    virtual void shutdown() override;

    virtual void enableStreaming(bool enable) override;

    virtual bool isStreamingEnabled() const override;

    virtual ~DataStreamROS() override;

    virtual const char* name() const override { return "ROS Topic Streamer";  }

    virtual void setParentMenu(QMenu* menu) override;

    virtual QDomElement xmlSaveState(QDomDocument &doc) const override;

    virtual bool xmlLoadState(QDomElement &parent_element ) override;

private:

    void topicCallback(const topic_tools::ShapeShifter::ConstPtr& msg, const std::string &topic_name);

    PlotDataMap _plot_data;

    bool _enabled;
    bool _running;

    std::shared_ptr<ros::AsyncSpinner> _spinner;

    void extractInitialSamples();

    double _initial_time;
    bool _use_header_timestamp;
    int _max_array_size;

    ros::NodeHandlePtr _node;
    std::vector<ros::Subscriber> _subscribers;
    RosIntrospection::SubstitutionRuleMap _rules;

    int _received_msg_count;

    QAction* _action_saveIntoRosbag;

    std::map<std::string, int> _msg_index;

    QStringList _default_topic_names;

    std::unique_ptr<RosIntrospection::Parser> _parser;
    bool _using_renaming_rules;

private slots:

    void saveIntoRosbag();
};

#endif // DATALOAD_CSV_H
